%global codename fuerte
%global shortname nxt

Name:		ros-%{codename}-nxt
Version:	0.1.2
Release:	3%{?dist}
Summary:	A ROS stack for interacting with Lego NXT
License:	BSD
URL:		http://ros.org/wiki/nxt
Source0:	https://code.ros.org/svn/release/download/stacks/nxt/nxt-%{version}/nxt-%{version}.tar.bz2
# Why do they have it download a separate source file as part of the build? Ugh.
Source1:	https://foote-ros-pkg.googlecode.com/files/nxt_description.parts.tar.gz
Patch0:		ros-nxt-nodownload.patch
Patch1:		ros-nxt-qtfix.patch
# Port to pluginlib for rxviz plugin
Patch2:		ros-nxt-pluginlib.patch
# nxt/sensor.py does this:
# from time import sleep, time
# So, we need to replace the calls to time.sleep() to just sleep()
Patch3:		ros-nxt-sleep-fix.patch
BuildRequires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
BuildRequires:	ros-%{codename}-geometry-devel, ros-%{codename}-common-msgs-devel
BuildRequires:	ros-%{codename}-orocos-kinematics-dynamics-devel, ros-%{codename}-visualization-devel
BuildRequires:	ros-%{codename}-pluginlib-devel
BuildRequires:	cmake, python-yaml, pyusb, pybluez
BuildRequires:	chrpath, nxt_python
Requires:	pyusb, pybluez, nxt_python
Provides:	ros-%{shortname} = %{version}-%{release}

%description
This stack has basic interfaces for interacting with ROS and NXT. The 
software in this stack is intended to run on top of the default NXT 
firmware provided by Lego.

%prep
%setup -q -c
# We have to do this so the cmake gunk can find itself. So idiotic.
mv %{shortname}-%{version} %{shortname}
%patch0 -p1 -b .nodownload
%patch1 -p1 -b .qtfix
%patch2 -p1 -b .pluginlib
%patch3 -p1 -b .fix

cp -a %{SOURCE1} %{shortname}/nxt_description/meshes/nxt_description.tar.gz

%build
cd %{shortname}
source /etc/catkin/profile.d/10.ros.all
export ROS_PACKAGE_PATH="%{_builddir}/%{name}-%{version}:$ROS_PACKAGE_PATH"
for i in nxt_controllers nxt_description nxt_lxf2urdf nxt_msgs nxt_ros nxt_rviz_plugin; do
  pushd $i
  mkdir build
  cd build
  %cmake -DSETUPTOOLS_DEB_LAYOUT=OFF ..
  make %{?_smp_mflags}
  popd
done

%install
cd %{shortname}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/
cp -a stack.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/

# nxt_controllers
pushd nxt_controllers
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_controllers
cp -a *.dox *.xml scripts %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_controllers/
popd

# nxt_description
pushd nxt_description
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_description/meshes
cp -a *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_description/
cp -a meshes/parts meshes/README %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_description/meshes/
popd

# nxt_lxf2urdf
pushd nxt_lxf2urdf
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_lxf2urdf
cp -a *.dox *.xml scripts %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_lxf2urdf/
popd

# nxt_msgs
pushd nxt_msgs
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_msgs/src
cp -a *.dox *.xml msg msg_gen %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_msgs/
mkdir -p %{buildroot}%{python_sitelib}
cp -a src/nxt_msgs %{buildroot}%{python_sitelib}/
ln -s %{python_sitelib}/nxt_msgs %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_msgs/src/nxt_msgs
popd

# nxt_python
pushd nxt_python
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_python/src
cp -a sensor_tests *.dox *.xml test_sensors.py *.config %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_python/
ln -s %{python_sitelib}/nxt %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_python/src/nxt
popd

# nxt_ros
pushd nxt_ros
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_ros
cp -a *.dox *.xml scripts %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_ros/
popd

# nxt_rviz_plugin
pushd nxt_rviz_plugin
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_rviz_plugin/lib
cp -a *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_rviz_plugin/
mkdir -p %{buildroot}%{_libdir}
cp -a lib/libnxt_rviz_plugin.so %{buildroot}%{_libdir}/libnxt_rviz_plugin.so
ln -s %{_libdir}/libnxt_rviz_plugin.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_rviz_plugin/lib/libnxt_rviz_plugin.so
cp -a lib/nxt_rviz_plugin.yaml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/nxt_rviz_plugin/lib/
popd

chrpath -d %{buildroot}%{_libdir}/*.so

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{python_sitelib}/nxt_msgs/
%{_libdir}/libnxt_rviz_plugin.so
%{_datadir}/ros-stacks/nxt/

%changelog
* Wed Jun  6 2012 Tom Callaway <spot@fedoraproject.org> - 0.1.2-3
- fix sleep calls in test scripts

* Wed Jun  6 2012 Tom Callaway <spot@fedoraproject.org> - 0.1.2-2
- add missing nxt_python manifest

* Tue Jun  5 2012 Tom Callaway <spot@fedoraproject.org> - 0.1.2-1
- initial package
